@@ -4,8 +4,7 @@ function(x, ...){
     z <- x
     cat("\nCall:\n", paste(deparse(z$call), sep = "\n", collapse = "\n"), 
         "\n\n", sep = "")
-    cat("Parameters:\n", " Observations = ", z$rank[1], ", Variables = ", z$rank[2], 
-         ", Bootstrap Replicates = ", z$N, sep="")    
+    cat("Parameters:\n", " Observations = ", z$rank[1], ", Variables = ", z$rank[2],"\n", sep="") 
     cat("\n\n")
     invisible(z)
 }
